/*
* Copyright (C) 2004 Ladislav Vitasek
* info@wordrider.net
* http://www.wordrider.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/
package net.wordrider.core.actions;

import net.wordrider.core.Lng;
import net.wordrider.core.MainApp;
import net.wordrider.dialogs.LoadingDialog;
import net.wordrider.utilities.SwingWorker;

/**
 * @author Vity
 */
public abstract class RiderSwingWorker extends SwingWorker {
    protected LoadingDialog dialogToClose = null;
    private final boolean showLoading;
    String errorMessage = "";

    public RiderSwingWorker(final boolean useLoadingDialog) {
        super();
        if (useLoadingDialog) {
            this.dialogToClose = new LoadingDialog(MainApp.getInstance().getMainAppFrame());
        }
        this.showLoading = useLoadingDialog;
    }

    public final void init() {
        start();
        if (showLoading) {
            dialogToClose.setVisible(true);
        }
    }

    public void finished() {
        super.finished();
        if (showLoading)
            dialogToClose.dispose();
    }

    protected final void showInfoWhileLoading(final String code) {
        if (showLoading)
            dialogToClose.setStatusText(Lng.getLabel(code));
    }

    public final String getErrorMessage() {
        return errorMessage;
    }
}
